@@ -297,9 +297,6 @@ void PlasmaDesktopTheme::syncColors()
     QPalette::ColorGroup group = (QPalette::ColorGroup)colorGroup();
     auto parentItem = qobject_cast<QQuickItem *>(parent());
     if (parentItem) {
-        if (!parentItem->isVisible()) {
-            return;
-        }
         if (!parentItem->isEnabled()) {
             group = QPalette::Disabled;
         } else if (m_window && !m_window->isActive() && m_window->isExposed()) {
